pub struct Error(/* private fields */);Implementations
Sourceimpl Error
impl Error
pub const ASM: Error
pub const ASM_ARCH: Error
pub const OK: Error
pub const NOMEM: Error
pub const ARCH: Error
pub const HANDLE: Error
pub const MODE: Error
pub const VERSION: Error
pub const OPT_INVALID: Error
pub const ASM_EXPR_TOKEN: Error
pub const ASM_DIRECTIVE_VALUE_RANGE: Error
pub const ASM_DIRECTIVE_ID: Error
pub const ASM_DIRECTIVE_TOKEN: Error
pub const ASM_DIRECTIVE_STR: Error
pub const ASM_DIRECTIVE_COMMA: Error
pub const ASM_DIRECTIVE_RELOC_NAME: Error
pub const ASM_DIRECTIVE_RELOC_TOKEN: Error
pub const ASM_DIRECTIVE_FPOINT: Error
pub const ASM_DIRECTIVE_UNKNOWN: Error
pub const ASM_DIRECTIVE_EQU: Error
pub const ASM_DIRECTIVE_INVALID: Error
pub const ASM_VARIANT_INVALID: Error
pub const ASM_EXPR_BRACKET: Error
pub const ASM_SYMBOL_MODIFIER: Error
pub const ASM_SYMBOL_REDEFINED: Error
pub const ASM_SYMBOL_MISSING: Error
pub const ASM_RPAREN: Error
pub const ASM_STAT_TOKEN: Error
pub const ASM_UNSUPPORTED: Error
pub const ASM_MACRO_TOKEN: Error
pub const ASM_MACRO_PAREN: Error
pub const ASM_MACRO_EQU: Error
pub const ASM_MACRO_ARGS: Error
pub const ASM_MACRO_LEVELS_EXCEED: Error
pub const ASM_MACRO_STR: Error
pub const ASM_MACRO_INVALID: Error
pub const ASM_ESC_BACKSLASH: Error
pub const ASM_ESC_OCTAL: Error
pub const ASM_ESC_SEQUENCE: Error
pub const ASM_ESC_STR: Error
pub const ASM_TOKEN_INVALID: Error
pub const ASM_INSN_UNSUPPORTED: Error
pub const ASM_FIXUP_INVALID: Error
pub const ASM_LABEL_INVALID: Error
pub const ASM_FRAGMENT_INVALID: Error
pub const ASM_INVALIDOPERAND: Error
pub const ASM_MISSINGFEATURE: Error
pub const ASM_MNEMONICFAIL: Error
Sourceimpl Error
impl Error
Sourcepub const fn bits(&self) -> i32
pub const fn bits(&self) -> i32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i32) -> Option<Error>
pub const fn from_bits(bits: i32) -> Option<Error>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i32) -> Error
pub const fn from_bits_truncate(bits: i32) -> Error
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i32) -> Error
pub const fn from_bits_retain(bits: i32) -> Error
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Error>
pub fn from_name(name: &str) -> Option<Error>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Error) -> bool
pub const fn intersects(&self, other: Error) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Error) -> bool
pub const fn contains(&self, other: Error) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Error)
pub fn remove(&mut self, other: Error)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Error)
pub fn toggle(&mut self, other: Error)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Error, value: bool)
pub fn set(&mut self, other: Error, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Error) -> Error
pub const fn intersection(self, other: Error) -> Error
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Error) -> Error
pub const fn union(self, other: Error) -> Error
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Error) -> Error
pub const fn difference(self, other: Error) -> Error
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Error) -> Error
pub const fn symmetric_difference(self, other: Error) -> Error
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Error
pub const fn complement(self) -> Error
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Error
impl Error
Sourcepub const fn iter(&self) -> Iter<Error>
pub const fn iter(&self) -> Iter<Error>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Error>
pub const fn iter_names(&self) -> IterNames<Error>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.